EHDropdownStyles class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildMenuItems<
T> ({required List< T> items, required String getLabel(T), }) → List<DropdownMenuItem< T> > -
dropdownDecoration(
{String? hintText, Widget? prefixIcon, double fontSize = 16, Color? hintTextColor, Color? borderColor, Color? focusedBorderColor, Widget? suffixIcon}) → InputDecoration -
dropdownMenuDecoration(
{Color? backgroundColor, Color? shadowColor}) → BoxDecoration -
dropdownMenuTextStyle(
{double fontSize = 16, Color? textColor}) → TextStyle -
dropdownTextStyle(
{double fontSize = 16, Color? textColor}) → TextStyle