EHExitBottomSheet class

Constructors

EHExitBottomSheet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, String title = 'Exit App', String message = 'Are you sure you want to exit the app?', String confirmText = 'Exit', String cancelText = 'Cancel', VoidCallback? onConfirm, VoidCallback? onCancel, Color? backgroundColor, double borderRadius = 20, bool isDismissible = true, bool enableDrag = true}) Future<bool?>
showWithCustomContent({required BuildContext context, required Widget child, Color? backgroundColor, double borderRadius = 20, bool isDismissible = true, bool enableDrag = true}) Future<bool?>