EHSnackBar class

Constructors

EHSnackBar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, required String message, EHSnackBarType type = EHSnackBarType.info, Duration? duration, String? actionLabel, VoidCallback? onActionPressed, bool showCloseIcon = true, EdgeInsetsGeometry? margin, double? borderRadius}) → void
showError({required BuildContext context, required String message, Duration? duration, String? actionLabel, VoidCallback? onActionPressed}) → void
showInfo({required BuildContext context, required String message, Duration? duration, String? actionLabel, VoidCallback? onActionPressed}) → void
showSuccess({required BuildContext context, required String message, Duration? duration, String? actionLabel, VoidCallback? onActionPressed}) → void
showWarning({required BuildContext context, required String message, Duration? duration, String? actionLabel, VoidCallback? onActionPressed}) → void