EHTextStyles class

A collection of text styles used throughout the Easy Home applications.

Constructors

EHTextStyles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

logotextstyle({required double fontSize, Color? color, FontWeight? fontWeight, double? letterSpacing}) TextStyle
Logo text style using Poppins font
textstyle({required double fontSize, Color? color, FontWeight? fontWeight, double? letterSpacing}) TextStyle
Text style that can be configured for any use case