EHButton class
A custom button widget that follows the Easy Home design system.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- EHButton
Constructors
- EHButton({Key? key, required VoidCallback? onPressed, required Widget child, ButtonStyle? style, bool isFullWidth = true, double? width, double? height, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? foregroundColor, double borderRadius = 8, double elevation = 0, TextStyle? textStyle})
-
Creates an Easy Home button.
const
Properties
- backgroundColor → Color?
-
The background color of the button.
final
- borderRadius → double
-
The border radius of the button.
final
- child → Widget
-
The child widget of the button.
final
- elevation → double
-
The elevation of the button.
final
- foregroundColor → Color?
-
The foreground color of the button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the button.
final
- isFullWidth → bool
-
Whether the button should take up the full width of its parent.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback?
-
The callback that is called when the button is tapped.
final
- padding → EdgeInsetsGeometry?
-
The padding of the button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ButtonStyle?
-
The style of the button.
final
- textStyle → TextStyle?
-
The text style of the button.
final
- width → double?
-
The width of the button.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited