EHButtonStyles class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
elevatedButtonStyle({Color? backgroundColor, Color? foregroundColor, double borderRadius = 8, double elevation = 0, TextStyle? textStyle, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(vertical: 18), Size minimumSize = const Size.fromHeight(56)})
→ ButtonStyle
-
-
outlinedButtonStyle({Color? borderColor, Color? foregroundColor, double borderRadius = 8, double borderWidth = 1.5, TextStyle? textStyle, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 14)})
→ ButtonStyle
-
-
textButtonStyle({Color? foregroundColor, double borderRadius = 8, TextStyle? textStyle, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 14)})
→ ButtonStyle
-