EHColors class
A collection of colors used throughout the Easy Home applications.
Constructors
- EHColors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accent → const Color
- Accent color for highlights and CTAs
- background → const Color
- Background color for the app
- disabled → const Color
- Disabled state color
- error → const Color
- Error color for error states and messages
- primary → const Color
- Primary brand color
- secondary → const Color
- Secondary brand color
- success → const Color
- Success color for success states and messages
- surface → const Color
- Surface color for cards and elevated elements
- textFieldBorder → const Color
- textFieldCursor → const Color
- textFieldHint → const Color
- textFieldPrefixIcon → const Color
- textFieldSuffixIcon → const Color
- textFieldText → const Color
- textHint → const Color
- textPrimary → const Color
- Text colors
- textSecondary → const Color
- warning → const Color
- Warning color for warning states and messages