SpacerSize class
Constructors
- SpacerSize(BuildContext context)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s10 ↔ double
-
latefinal
- s12 ↔ double
-
latefinal
- s14 ↔ double
-
latefinal
- s16 ↔ double
-
latefinal
- s2 ↔ double
-
latefinal
- s20 ↔ double
-
latefinal
- s24 ↔ double
-
latefinal
- s28 ↔ double
-
latefinal
- s32 ↔ double
-
latefinal
- s4 ↔ double
-
latefinal
- s40 ↔ double
-
latefinal
- s48 ↔ double
-
latefinal
- s56 ↔ double
-
latefinal
- s6 ↔ double
-
latefinal
- s64 ↔ double
-
latefinal
- s8 ↔ double
-
latefinal
- scaleFactor → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
custom(
BuildContext context, double multiplier) → double - Custom spacing with custom multiplier
-
getAllSizes(
BuildContext context) → Map< String, double> - Get all spacer sizes as a map for easy access
-
getByType(
BuildContext context, String type) → double - Get spacing by type string